@@ -7,6 +7,7 @@
 #include <a0/packet.hpp>
 #include <a0/string_view.hpp>
 #include <a0/tid.h>
+#include <a0/time.hpp>
 
 #include <cstdint>
 #include <functional>
@@ -48,21 +49,32 @@ struct CfgTopic {
 
 struct Cfg : details::CppWrap<a0_cfg_t> {
   Cfg() = default;
+  Cfg(const Cfg&) = default;
   explicit Cfg(CfgTopic);
 
-  Packet read(int flags = 0) const;
+  Packet read() const;
+  Packet read_blocking() const;
+  Packet read_blocking(TimeMono) const;
 
   void write(Packet);
-
   void write(const char cstr[]) {
     write(Packet(cstr, ref));
   }
 
+  bool write_if_empty(Packet);
+  bool write_if_empty(const char cstr[]) {
+    return write_if_empty(Packet(cstr, ref));
+  }
+
 #ifdef A0_EXT_NLOHMANN
 
   void write(nlohmann::json j) {
     write(Packet(j.dump()));
   }
+  bool write_if_empty(nlohmann::json j) {
+    return write_if_empty(Packet(j.dump()));
+  }
+
   void mergepatch(nlohmann::json);
 
  private:
@@ -71,17 +83,31 @@ struct Cfg : details::CppWrap<a0_cfg_t> {
  public:
   template <typename T>
   class Var {
-    std::shared_ptr<Cfg> parent;
-    nlohmann::json::json_pointer jptr;
-    std::shared_ptr<std::function<void(const nlohmann::json&)>> updater;
-    mutable T cache;
+    struct Impl {
+      std::shared_ptr<Cfg> parent;
+      nlohmann::json::json_pointer jptr;
+      std::shared_ptr<std::function<void(const nlohmann::json&)>> updater;
+      T cache;
+      bool cache_populated{false};
+    };
+    std::shared_ptr<Impl> impl;
 
     void create_updater() {
-      updater = std::make_shared<std::function<void(const nlohmann::json&)>>(
-          [this](const nlohmann::json& full_cfg) {
-            full_cfg[jptr].get_to(cache);
+      std::weak_ptr<Impl> weak_impl = impl;
+      impl->updater = std::make_shared<std::function<void(const nlohmann::json&)>>(
+          [weak_impl](const nlohmann::json& full_cfg) {
+            auto strong_impl = weak_impl.lock();
+            if (!strong_impl) {
+              return;
+            }
+            try {
+              full_cfg[strong_impl->jptr].get_to(strong_impl->cache);
+              strong_impl->cache_populated = true;
+            } catch (...) {
+              strong_impl->cache_populated = false;
+            }
           });
-      parent->register_var(updater);
+      impl->parent->register_var(impl->updater);
     }
 
    public:
@@ -89,35 +115,38 @@ struct Cfg : details::CppWrap<a0_cfg_t> {
     Var(const Var& other) {
       *this = other;
     }
-    Var(Var&& other) {
+    Var(Var&& other) noexcept {
       *this = std::move(other);
     }
     Var(Cfg parent_, std::string jptr_str)
-        : parent{std::make_shared<Cfg>(parent_)}, jptr{jptr_str} {
+        : impl{std::make_shared<Impl>()} {
+      impl->parent = std::make_shared<Cfg>(parent_);
+      impl->jptr = nlohmann::json::json_pointer{jptr_str};
       create_updater();
-      Packet pkt = parent->read();
-      const char* begin = pkt.payload().data();
-      const char* end = begin + pkt.payload().size();
-      (*updater)(nlohmann::json::parse(begin, end));
+      try {
+        Packet pkt = impl->parent->read();
+        const char* begin = pkt.payload().data();
+        const char* end = begin + pkt.payload().size();
+        (*impl->updater)(nlohmann::json::parse(begin, end));
+      } catch (...) {
+      }
     }
 
     Var& operator=(const Var& other) {
-      parent = other.parent;
-      jptr = other.jptr;
-      cache = other.cache;
-      create_updater();
+      impl = other.impl;
       return *this;
     }
-    Var& operator=(Var&& other) {
-      parent = other.parent;
-      jptr = std::move(other.jptr);
-      cache = std::move(other.cache);
-      create_updater();
+
+    Var& operator=(Var&& other) noexcept {
+      impl = std::move(other.impl);
       return *this;
     }
 
     const T& operator*() const {
-      return cache;
+      if (!impl->cache_populated) {
+        throw std::runtime_error("Cfg::Var has no data.");
+      }
+      return impl->cache;
     }
 
     const T* operator->() const {
