@@ -31,22 +31,28 @@ struct Publisher : details::CppWrap<a0_publisher_t> {
   explicit Publisher(PubSubTopic);
 
   void pub(Packet);
-  void pub(string_view sv) { pub(Packet(sv, ref)); }
+  void pub(std::unordered_multimap<std::string, std::string> headers,
+           string_view payload) {
+    pub(Packet(std::move(headers), payload, ref));
+  }
+  void pub(string_view payload) {
+    pub({}, payload);
+  }
 };
 
 struct SubscriberSync : details::CppWrap<a0_subscriber_sync_t> {
   SubscriberSync() = default;
   SubscriberSync(PubSubTopic, ReaderInit, ReaderIter);
 
-  bool has_next();
-  Packet next();
+  bool can_read();
+  Packet read();
+  Packet read_blocking();
+  Packet read_blocking(TimeMono);
 };
 
 struct Subscriber : details::CppWrap<a0_subscriber_t> {
   Subscriber() = default;
   Subscriber(PubSubTopic, ReaderInit, ReaderIter, std::function<void(Packet)>);
-
-  static Packet read_one(PubSubTopic, ReaderInit, int flags);
 };
 
 }  // namespace a0
